use maud::{PreEscaped, html};

pub mod aspect;
pub mod background;
pub mod container;
pub mod div;
pub mod flex;
pub mod header;
pub mod image;
pub mod input;
pub mod link;
pub mod padding;
pub mod rounded;
pub mod shadow;
pub mod sized;
pub mod space;
pub mod text;
pub mod width;

#[allow(non_snake_case)]
pub fn Nothing() -> PreEscaped<String> {
    html! {}
}

/// Generates a `<script>` element containing the provided JavaScript code.
///
/// This function wraps the provided JavaScript code in a `<script>` tag,
/// allowing for easy inclusion of custom scripts in the rendered HTML.
///
/// # Arguments
/// * `script` - The JavaScript code to include.
///
/// # Returns
/// A `PreEscaped<String>` containing the rendered `<script>` element.
#[must_use]
pub fn script(script: &str) -> PreEscaped<String> {
    html!(
        script {
            (PreEscaped(script))
        };
    )
}

pub enum Size {
    None,
    Small,
    Regular,
    Medium,
    Large,
    XL,
    _2XL,
    _3XL,
    Full,
}

impl Size {
    pub fn to_string(&self) -> &str {
        match self {
            Self::None => "none",
            Self::Small => "sm",
            Self::Regular => "",
            Self::Medium => "md",
            Self::Large => "lg",
            Self::XL => "xl",
            Self::_2XL => "2xl",
            Self::_3XL => "3xl",
            Self::Full => "full",
        }
    }
}

pub enum Side {
    Start,
    End,
    Top,
    Right,
    Bottom,
    Left,
    StartStart,
    StartEnd,
    EndEnd,
    EndStart,
    TopLeft,
    TopRight,
    BottomRight,
    BottomLeft,
}

impl Side {
    pub fn to_string(&self) -> &str {
        match self {
            Side::Start => "s",
            Side::End => "e",
            Side::Top => "t",
            Side::Right => "r",
            Side::Bottom => "b",
            Side::Left => "l",
            Side::StartStart => "ss",
            Side::StartEnd => "se",
            Side::EndEnd => "ee",
            Side::EndStart => "es",
            Side::TopLeft => "tl",
            Side::TopRight => "tr",
            Side::BottomRight => "br",
            Side::BottomLeft => "bl",
        }
    }
}
